@@ -12,12 +12,13 @@ try:
 except ImportError:
     pypd = None
 
+
 from great_expectations.data_context.util import instantiate_class_from_config
 
 from ..data_context.store.metric_store import MetricStore
 from ..data_context.types.resource_identifiers import ValidationResultIdentifier
 from ..exceptions import ClassInstantiationError, DataContextError
-from .util import send_slack_notification
+from .util import send_slack_notification, send_opsgenie_alert
 
 logger = logging.getLogger(__name__)
 
@@ -63,7 +64,8 @@ class ValidationAction:
 
 class NoOpAction(ValidationAction):
     def __init__(
-        self, data_context,
+        self,
+        data_context,
     ):
         super().__init__(data_context)
 
@@ -268,6 +270,114 @@ PagerdutyAlertAction sends a pagerduty event
         return {"pagerduty_alert_result": "none sent"}
 
 
+class OpsgenieAlertAction(ValidationAction):
+    """
+    OpsgenieAlertAction creates and sends an Opsgenie alert
+
+    **Configuration**
+
+    .. code-block:: yaml
+
+        - name: send_opsgenie_alert_on_validation_result
+        action:
+          class_name: OpsgenieAlertAction
+          # put the actual webhook URL in the uncommitted/config_variables.yml file
+          api_key: ${opsgenie_api_key} # Opsgenie API key
+          region: specifies the Opsgenie region. Populate 'EU' for Europe otherwise leave empty
+          priority: specify the priority of the alert (P1 - P5) defaults to P3
+          notify_on: failure # possible values: "all", "failure", "success"
+
+    """
+
+    def __init__(
+        self,
+        data_context,
+        renderer,
+        api_key,
+        region=None,
+        priority="P3",
+        notify_on="failure",
+    ):
+        """Construct a OpsgenieAlertAction
+
+        Args:
+            data_context:
+            api_key: Opsgenie API key
+            region: specifies the Opsgenie region. Populate 'EU' for Europe otherwise do not set
+            priority: specify the priority of the alert (P1 - P5) defaults to P3
+            notify_on: "all", "failure", "success" - specifies validation status that will trigger notification
+        """
+        super().__init__(data_context)
+        self.renderer = instantiate_class_from_config(
+            config=renderer,
+            runtime_environment={},
+            config_defaults={},
+        )
+        module_name = renderer["module_name"]
+        if not self.renderer:
+            raise ClassInstantiationError(
+                module_name=module_name,
+                package_name=None,
+                class_name=renderer["class_name"],
+            )
+
+        self.api_key = api_key
+        assert api_key, "opsgenie_api_key missing in config_variables.yml"
+        self.region = region
+        self.priority = priority
+        self.notify_on = notify_on
+
+    def _run(
+        self,
+        validation_result_suite,
+        validation_result_suite_identifier,
+        data_asset=None,
+        payload=None,
+    ):
+        logger.debug("OpsgenieAlertAction.run")
+
+        if validation_result_suite is None:
+            return
+
+        if not isinstance(
+            validation_result_suite_identifier, ValidationResultIdentifier
+        ):
+            raise TypeError(
+                "validation_result_suite_id must be of type ValidationResultIdentifier, not {}".format(
+                    type(validation_result_suite_identifier)
+                )
+            )
+
+        validation_success = validation_result_suite.success
+
+        if (
+            self.notify_on == "all"
+            or self.notify_on == "success"
+            and validation_success
+            or self.notify_on == "failure"
+            and not validation_success
+        ):
+            expectation_suite_name = validation_result_suite.meta.get(
+                "expectation_suite_name", "__no_expectation_suite_name__"
+            )
+
+            settings = {
+                "api_key": self.api_key,
+                "region": self.region,
+                "priority": self.priority,
+            }
+
+            description = self.renderer.render(validation_result_suite, None, None)
+
+            alert_result = send_opsgenie_alert(
+                description, expectation_suite_name, settings
+            )
+
+            return {"opsgenie_alert_result": alert_result}
+        else:
+            return {"opsgenie_alert_result": ""}
+
+
 class StoreValidationResultAction(ValidationAction):
     """
     StoreValidationResultAction stores a validation result in the ValidationsStore.
